@@ -1,28 +1,12 @@
 from autograd.extend import primitive, defvjp_argnums
 from plum import Dispatcher
 
+from ..util import as_tuple
+
 __all__ = ['autograd_register']
 _dispatch = Dispatcher()
 
 
-@_dispatch(tuple)
-def as_tuple(x):
-    """Get `x` as a tuple. Will be wrapped in a one-tuple if it is not a tuple.
-
-    Args:
-        x (object): Object to get as a tuple.
-
-    Returns:
-        tuple: `x` as a tuple.
-    """
-    return x
-
-
-@_dispatch(object)
-def as_tuple(x):
-    return (x,)
-
-
 def autograd_register(f, s_f):
     """Register a function and its sensitivity for AutoGrad.
 
