@@ -4,7 +4,7 @@ import numpy as np
 import scipy.linalg as sla
 
 # noinspection PyUnresolvedReferences
-from .bvn_cdf import bvn_cdf, s_bvn_cdf
+from .bvn_cdf import bvn_cdf as bvn_cdf_, s_bvn_cdf
 
 __all__ = ['toeplitz_solve', 's_toeplitz_solve',
            'bvn_cdf', 's_bvn_cdf',
@@ -84,6 +84,12 @@ def s_toeplitz_solve(s_y, y, a, b, c):
     return s_a, s_b, s_c
 
 
+def bvn_cdf(a, b, c):
+    # We do not directly use `bvn_cdf_` to not have `inspect.signature` fail, which
+    # does not work for `bvn_cdf_`.
+    return bvn_cdf_(a, b, c)
+
+
 def expm(a):
     return sla.expm(a)
 
