@@ -11,6 +11,7 @@ from .types import (
     AGNumeric,
     TFNumeric,
     TorchNumeric,
+    JaxNumeric
 )
 from .util import abstract
 
@@ -897,6 +898,7 @@ NPOrNum = {NPNumeric, Number}  #: Type NumPy numeric or number.
 add_conversion_method(AGNumeric, NPOrNum, lambda x: x._value)
 add_conversion_method(TFNumeric, NPOrNum, lambda x: x.numpy())
 add_conversion_method(TorchNumeric, NPOrNum, lambda x: x.detach().numpy())
+add_conversion_method(JaxNumeric, NPOrNum, np.array)
 
 
 @dispatch(object)
