@@ -34,22 +34,22 @@ def diag(a):
 
 
 @dispatch(Numeric)
-def vec_to_tril(a):
+def vec_to_tril(a, offset=0):
     if B.rank(a) != 1:
         raise ValueError('Input must be rank 1.')
-    m, upper, perm = _vec_to_tril_shape_upper_perm(a)
+    side, upper, perm = _vec_to_tril_shape_upper_perm(a, offset=offset)
     a = tf.concat((a, tf.zeros(upper, dtype=a.dtype)), axis=0)
-    return tf.reshape(tf.gather(a, perm), [m, m])
+    return tf.reshape(tf.gather(a, perm), [side, side])
 
 
 @dispatch(Numeric)
-def tril_to_vec(a):
+def tril_to_vec(a, offset=0):
     if B.rank(a) != 2:
         raise ValueError('Input must be rank 2.')
     n, m = a.shape
     if n != m:
         raise ValueError('Input must be square.')
-    return tf.gather_nd(a, list(zip(*np.tril_indices(int(n)))))
+    return tf.gather_nd(a, list(zip(*np.tril_indices(int(n), k=offset))))
 
 
 @dispatch([Numeric])
