@@ -23,12 +23,14 @@ __all__ = ['Int',
            'AGNumeric',
            'TFNumeric',
            'TorchNumeric',
+           'JaxNumeric',
            'Numeric',
 
            'NPDType',
            'AGDType',
            'TFDType',
            'TorchDType',
+           'JaxDType',
            'DType',
 
            'default_dtype',
@@ -39,10 +41,12 @@ __all__ = ['Int',
            'AG',
            'TF',
            'Torch',
+           'Jax',
            'Framework',
 
            '_tf_retrievables',
-           '_torch_retrievables']
+           '_torch_retrievables',
+           '_jax_retrievables']
 
 
 @parametric
@@ -108,6 +112,12 @@ _torch_retrievables = [_torch_tensor, _torch_dtype]
 _ag_tensor = ModuleType('autograd.tracer', 'Box')
 _ag_retrievables = [_ag_tensor]
 
+# Define Jax module types.
+_jax_tensor = ModuleType('jax.interpreters.xla', 'DeviceArray')
+_jax_tracer = ModuleType('jax.core', 'Tracer')
+_jax_dtype = ModuleType('jax._src.numpy.lax_numpy', '_ScalarMeta')
+_jax_retrievables = [_jax_tensor, _jax_tracer, _jax_dtype]
+
 # Numeric types:
 Int = Union(*([int] + np.sctypes['int'] + np.sctypes['uint']), alias='Int')
 Float = Union(*([float] + np.sctypes['float']), alias='Float')
@@ -119,27 +129,33 @@ TFNumeric = Union(_tf_tensor,
                   _tf_variable,
                   _tf_indexedslices, alias='TFNumeric')
 TorchNumeric = Union(_torch_tensor, alias='TorchNumeric')
+JaxNumeric = Union(_jax_tensor, _jax_tracer, alias='JaxNumeric')
 Numeric = Union(Number,
                 NPNumeric,
                 AGNumeric,
                 TFNumeric,
+                JaxNumeric,
                 TorchNumeric, alias='Numeric')
 
 # Define corresponding promotion rules and conversion methods.
 add_promotion_rule(NPNumeric, TFNumeric, TFNumeric)
 add_promotion_rule(NPNumeric, TorchNumeric, TorchNumeric)
+add_promotion_rule(NPNumeric, JaxNumeric, JaxNumeric)
 add_promotion_rule(_tf_tensor, _tf_variable, TFNumeric)
 add_conversion_method(NPNumeric, TFNumeric,
                       lambda x: _module_call('tensorflow', 'constant', x))
 add_conversion_method(NPNumeric, TorchNumeric,
                       lambda x: _module_call('torch', 'tensor', x))
+add_conversion_method(NPNumeric, JaxNumeric,
+                      lambda x: _module_call('jax.numpy', 'asarray', x))
 
 # Data types:
 NPDType = Union(type, np.dtype, alias='NPDType')
 AGDType = Union(NPDType, alias='AGDType')
 TFDType = Union(_tf_dtype, alias='TFDType')
 TorchDType = Union(_torch_dtype, alias='TorchDType')
-DType = Union(NPDType, TFDType, TorchDType, alias='DType')
+JaxDType = Union(_jax_dtype, alias='JaxDType')
+DType = Union(NPDType, TFDType, TorchDType, JaxDType, alias='DType')
 
 # Create lookup for PyTorch data types that loads upon the first request.
 _torch_lookup_cache = {}
@@ -177,14 +193,26 @@ add_conversion_method(NPDType, TFDType,
                       lambda x: _module_attr('tensorflow', _name(x)))
 add_conversion_method(NPDType, TorchDType,
                       lambda x: _module_attr('torch', _name(x)))
+add_conversion_method(NPDType, JaxDType,
+                      lambda x: _module_attr('jax.numpy', _name(x)))
 add_conversion_method(TorchDType, NPDType, _torch_lookup)
 add_conversion_method(TorchDType, TFDType,
                       lambda x: _module_attr('tensorflow',
                                              _name(_torch_lookup(x))))
+add_conversion_method(TorchDType, JaxDType,
+                      lambda x: _module_attr('jax.numpy',
+                                             _name(_torch_lookup(x))))
 add_conversion_method(TFDType, NPDType, lambda x: x.as_numpy_dtype)
 add_conversion_method(TFDType, TorchDType,
                       lambda x: _module_attr('torch',
                                              _name(x.as_numpy_dtype)))
+add_conversion_method(TFDType, JaxDType,
+                      lambda x: _module_attr('jax.numpy',
+                                             _name(x.as_numpy_dtype)))
+add_conversion_method(JaxDType, NPDType, lambda x: x.dtype.type)
+add_conversion_method(JaxDType, TFDType,
+                      lambda x: _module_attr('tensorflow', _name(x.dtype)))
+add_conversion_method(JaxDType, TorchDType, lambda x: _module_attr('torch', _name(x)))
 
 default_dtype = np.float64  #: Default dtype.
 
@@ -215,15 +243,36 @@ def dtype(a):
     Args:
         a (tensor): Object to determine data type of.
     """
+    return a.dtype
+
+
+@dispatch({Number, NPNumeric})
+def dtype(a):
     try:
-        return a.dtype
+        # For the sake of consistency, return the underlying data type, and not a
+        # `np.type`.
+        return a.dtype.type
     except AttributeError:
+        # It is likely a built-in. Its data type is then given by its type.
         return type(a)
 
 
+@dispatch(AGNumeric)
+def dtype(a):
+    # See above.
+    return a.dtype.type
+
+
+@dispatch(JaxNumeric)
+def dtype(a):
+    # Jax gives NumPy data types back. Convert to Jax ones.
+    return convert(a.dtype, JaxDType)
+
+
 # Framework types:
 NP = Union(NPNumeric, NPDType, alias='NP')
 AG = Union(AGNumeric, AGDType, alias='AG')
 TF = Union(TFNumeric, TFDType, alias='TF')
 Torch = Union(TorchNumeric, TorchDType, alias='Torch')
-Framework = Union(NP, TF, Torch, alias='Framework')
+Jax = Union(JaxNumeric, JaxDType, alias='Jax')
+Framework = Union(NP, TF, Torch, Jax, alias='Framework')
