@@ -1,10 +1,10 @@
+import jax
 import pytest
-
-import lab as B
 import tensorflow as tf
 from autograd import grad
 from fdm import check_sensitivity, gradient
-from lab.autograd.custom import as_tuple
+
+import lab as B
 from lab.custom import (
     toeplitz_solve, s_toeplitz_solve,
     bvn_cdf, s_bvn_cdf,
@@ -12,27 +12,24 @@ from lab.custom import (
     logm, s_logm
 )
 from lab.tensorflow.custom import as_tf
-from lab.torch.custom import as_torch, as_np
-
+from lab.torch.custom import as_torch
+from lab.jax.custom import as_jax
 from .util import approx
 
 
-def test_as_tuple():
-    assert as_tuple(1) == (1,)
-    assert as_tuple((1,)) == (1,)
-    assert as_tuple((1, 2)) == (1, 2)
-
-
 def test_as_tf():
     assert isinstance(as_tf(B.randn()), B.TFNumeric)
     assert isinstance(as_tf((B.randn(),))[0], B.TFNumeric)
 
 
-def test_as_torch_and_as_np():
+def test_as_torch():
     assert isinstance(as_torch(B.randn()), B.TorchNumeric)
     assert isinstance(as_torch((B.randn(),))[0], B.TorchNumeric)
-    assert isinstance(as_np(as_torch(B.randn())), B.NPNumeric)
-    assert isinstance(as_np(as_torch((B.randn(),)))[0], B.NPNumeric)
+
+
+def test_as_jax():
+    assert isinstance(as_jax(B.randn()), B.JaxNumeric)
+    assert isinstance(as_jax((B.randn(),))[0], B.JaxNumeric)
 
 
 def check_grad(f, args, kw_args=None, digits=6):
@@ -84,6 +81,12 @@ def check_grad(f, args, kw_args=None, digits=6):
         f_i(torch_args[i]).backward()
         approx(numerical_grad, torch_args[i].grad, digits)
 
+        # Check Jax gradient.
+        torch_args = tuple([jax.device_put(arg) for arg in args])
+        f_i = create_f_i(i, torch_args)
+        jax_grad = jax.grad(f_i)(args[i])
+        approx(numerical_grad, jax_grad, digits)
+
 
 def test_toeplitz_solve():
     check_sensitivity(toeplitz_solve, s_toeplitz_solve,
