@@ -1,3 +1,4 @@
+import jax.numpy as jnp
 import numpy as np
 import pytest
 import scipy.special
@@ -15,8 +16,7 @@ from .util import (
     BoolTensor,
     NaNTensor,
     Bool,
-    allclose,
-    dtype_equal
+    allclose
 )
 
 
@@ -35,7 +35,7 @@ def test_isnan():
 @pytest.mark.parametrize('f', [B.zeros, B.ones, B.eye])
 def test_zeros_ones_eye(f):
     # Check consistency.
-    check_function(f, (Value(np.float32, tf.float32, torch.float32),
+    check_function(f, (Value(np.float32, tf.float32, torch.float32, jnp.float32),
                        Value(2),
                        Value(3)))
 
@@ -50,7 +50,8 @@ def test_zeros_ones_eye(f):
     # Check reference calls.
     for t1, t2 in [(np.float32, np.int64),
                    (tf.float32, tf.int64),
-                   (torch.float32, torch.int64)]:
+                   (torch.float32, torch.int64),
+                   (jnp.float32, jnp.int64)]:
         ref = B.randn(t1, 4, 5)
 
         # Check shape of calls.
@@ -59,25 +60,25 @@ def test_zeros_ones_eye(f):
         assert B.shape(f(ref)) == (4, 5)
 
         # Check type of calls.
-        assert B.dtype(f(t2, 2)) == t2
-        assert B.dtype(f(t2, 2, 3)) == t2
-        assert B.dtype(f(ref)) == t1
+        assert B.dtype(f(t2, 2)) is t2
+        assert B.dtype(f(t2, 2, 3)) is t2
+        assert B.dtype(f(ref)) is t1
 
 
 @pytest.mark.parametrize('f', [B.zero, B.one])
 def test_zero_one(f):
     # Check consistency.
-    check_function(f, (Value(np.float32, tf.float32, torch.float32),))
+    check_function(f, (Value(np.float32, tf.float32, torch.float32, jnp.float32),))
 
     # Check reference calls.
-    for t in [np.float32, tf.float32, torch.float32]:
-        assert B.dtype(f(B.randn(t))) == t
+    for t in [np.float32, tf.float32, torch.float32, jnp.float32]:
+        assert B.dtype(f(B.randn(t))) is t
 
 
 def test_eye_exceptions():
     with pytest.raises(NotFoundLookupError):
         B.eye(3, 4, 5)
-    for t in [np.float32, tf.float32, torch.float32]:
+    for t in [np.float32, tf.float32, torch.float32, jnp.float32]:
         with pytest.raises(NotFoundLookupError):
             B.eye(t, 3, 4, 5)
 
@@ -86,8 +87,11 @@ def test_linspace():
     # Check correctness.
     allclose(B.linspace(0, 1, 10), np.linspace(0, 1, 10, dtype=B.default_dtype))
 
-    # Check consistency
-    check_function(B.linspace, (Value(np.float32, tf.float32, torch.float32),
+    # Check consistency.
+    check_function(B.linspace, (Value(np.float32,
+                                      tf.float32,
+                                      torch.float32,
+                                      jnp.float32),
                                 Value(0),
                                 Value(10),
                                 Value(20)))
@@ -101,42 +105,48 @@ def test_range():
 
     # Check various step sizes.
     for step in [1, 1.0, 0.25]:
-        check_function(B.range, (Value(np.float32, tf.float32, torch.float32),
+        check_function(B.range, (Value(np.float32,
+                                       tf.float32,
+                                       torch.float32,
+                                       jnp.float32),
                                  Value(0),
                                  Value(5),
                                  Value(step)))
 
     # Check two-argument specification.
-    check_function(B.range, (Value(np.float32, tf.float32, torch.float32),
+    check_function(B.range, (Value(np.float32, tf.float32, torch.float32, jnp.float32),
                              Value(0),
                              Value(5)))
 
     # Check one-argument specification.
-    check_function(B.range, (Value(np.float32, tf.float32, torch.float32),
+    check_function(B.range, (Value(np.float32, tf.float32, torch.float32, jnp.float32),
                              Value(5)))
 
 
 def test_cast():
     # Test casting to a given data type.
-    dtype_equal(B.dtype(B.cast(np.float64, 1)), np.float64)
-    dtype_equal(B.dtype(B.cast(np.float64, np.array(1))), np.float64)
+    assert B.dtype(B.cast(np.float64, 1)) is np.float64
+    assert B.dtype(B.cast(np.float64, np.array(1))) is np.float64
+    assert B.dtype(B.cast(np.float64, autograd_box(np.float32(1)))) is np.float64
 
-    dtype_equal(B.dtype(B.cast(np.float64, autograd_box(np.float32(1)))),
-                np.float64)
+    assert B.dtype(B.cast(tf.float64, 1)) is tf.float64
+    assert B.dtype(B.cast(tf.float64, np.array(1))) is tf.float64
+    assert B.dtype(B.cast(tf.float64, tf.constant(1))) is tf.float64
 
-    dtype_equal(B.dtype(B.cast(tf.float64, 1)), tf.float64)
-    dtype_equal(B.dtype(B.cast(tf.float64, np.array(1))), tf.float64)
-    dtype_equal(B.dtype(B.cast(tf.float64, tf.constant(1))), tf.float64)
+    assert B.dtype(B.cast(torch.float64, 1)) is torch.float64
+    assert B.dtype(B.cast(torch.float64, np.array(1))) is torch.float64
+    assert B.dtype(B.cast(torch.float64, torch.tensor(1))) is torch.float64
 
-    dtype_equal(B.dtype(B.cast(torch.float64, 1)), torch.float64)
-    dtype_equal(B.dtype(B.cast(torch.float64, np.array(1))), torch.float64)
-    dtype_equal(B.dtype(B.cast(torch.float64, torch.tensor(1))), torch.float64)
+    assert B.dtype(B.cast(jnp.float64, 1)) is jnp.float64
+    assert B.dtype(B.cast(jnp.float64, np.array(1))) is jnp.float64
+    assert B.dtype(B.cast(jnp.float64, jnp.array(1))) is jnp.float64
 
     # Test that casting to its own data type does nothing.
     for x in [B.randn(np.float32),
               autograd_box(B.randn(np.float32)),
               B.randn(tf.float32),
-              B.randn(torch.float32)]:
+              B.randn(torch.float32),
+              B.randn(jnp.float32)]:
         assert x is B.cast(B.dtype(x), x)
 
 
@@ -222,6 +232,12 @@ def test_logical_comparisons(f):
     check_function(f, (Tensor(2, 3), Tensor(2, 3)), {}, assert_dtype=False)
 
 
+def test_bvn_cdf():
+    check_function(B.bvn_cdf,
+                   (PositiveTensor(5), PositiveTensor(5), PositiveTensor(5)),
+                   {}, assert_dtype=False)
+
+
 def test_scan():
     # Check consistency by inputting various shapes for a simple scanning
     # function.
