@@ -1,3 +1,5 @@
+import jax
+import jax.numpy as jnp
 import numpy as np
 import pytest
 import tensorflow as tf
@@ -6,7 +8,6 @@ from autograd import grad
 from plum.promotion import _promotion_rule, convert
 
 import lab as B
-from .util import dtype_equal
 
 
 def test_numeric():
@@ -31,6 +32,9 @@ def test_numeric():
     # Test Torch.
     assert isinstance(torch.tensor(1), B.TorchNumeric)
 
+    # Test Jax.
+    assert isinstance(jnp.array(1), B.JaxNumeric)
+
     # Test general numeric type.
     assert isinstance(1, B.Numeric)
     assert isinstance(np.bool_(1), B.Numeric)
@@ -44,12 +48,14 @@ def test_numeric():
     assert _promotion_rule(np.array(1), tf.Variable(1)) == B.TFNumeric
     assert _promotion_rule(tf.constant(1), tf.Variable(1)) == B.TFNumeric
     assert _promotion_rule(np.array(1), torch.tensor(1)) == B.TorchNumeric
+    assert _promotion_rule(np.array(1), jnp.array(1)) == B.JaxNumeric
     with pytest.raises(TypeError):
         _promotion_rule(B.TFNumeric, B.TorchNumeric)
 
     # Test conversion.
     assert isinstance(convert(np.array(1), B.TFNumeric), B.TFNumeric)
     assert isinstance(convert(np.array(1), B.TorchNumeric), B.TorchNumeric)
+    assert isinstance(convert(np.array(1), B.JaxNumeric), B.JaxNumeric)
 
 
 def test_autograd_tracing():
@@ -71,6 +77,22 @@ def test_autograd_tracing():
         assert isinstance(obj, B.AGNumeric)
 
 
+def test_jax_tracing():
+    found_objs = []
+
+    def f(x):
+        found_objs.append(x)
+        return B.sum(x)
+
+    # Catch Jax object during JIT and during gradient computation.
+    jax.grad(f)(np.ones(5))
+    jax.jit(f)(np.ones(5))
+
+    # Test that objects are of the right type.
+    for obj in found_objs:
+        assert isinstance(obj, B.JaxNumeric)
+
+
 def test_data_type():
     assert isinstance(np.float32, B.NPDType)
     assert isinstance(np.float32, B.DType)
@@ -78,37 +100,50 @@ def test_data_type():
     assert isinstance(tf.float32, B.DType)
     assert isinstance(torch.float32, B.TorchDType)
     assert isinstance(torch.float32, B.DType)
+    assert isinstance(jnp.float32, B.JaxDType)
+    assert isinstance(jnp.float32, B.DType)
+
+    # Check that the AutoGrad and Jax data types are just the NumPy data type. Then
+    # there is nothing left to check.
+    assert B.AGDType == B.NPDType
 
     # Test conversion between data types.
-    dtype_equal(convert(np.float32, B.TFDType), tf.float32)
-    dtype_equal(convert(np.float32, B.TorchDType), torch.float32)
-    dtype_equal(convert(tf.float32, B.NPDType), np.float32)
-    dtype_equal(convert(tf.float32, B.TorchDType), torch.float32)
-    dtype_equal(convert(torch.float32, B.NPDType), np.float32)
-    dtype_equal(convert(torch.float32, B.TFDType), tf.float32)
-
-    # Test conversion of `np.dtype`.
-    dtype_equal(convert(np.dtype('float32'), B.DType), np.float32)
+    assert convert(np.float32, B.TFDType) is tf.float32
+    assert convert(np.float32, B.TorchDType) is torch.float32
+    assert convert(np.float32, B.JaxDType) is jnp.float32
+    assert convert(tf.float32, B.NPDType) is np.float32
+    assert convert(tf.float32, B.TorchDType) is torch.float32
+    assert convert(tf.float32, B.JaxDType) is jnp.float32
+    assert convert(torch.float32, B.NPDType) is np.float32
+    assert convert(torch.float32, B.TFDType) is tf.float32
+    assert convert(torch.float32, B.JaxDType) is jnp.float32
+    assert convert(jnp.float32, B.NPDType) is np.float32
+    assert convert(jnp.float32, B.TFDType) is tf.float32
+    assert convert(jnp.float32, B.TorchDType) is torch.float32
 
 
 def test_issubdtype():
     assert B.issubdtype(np.float32, np.floating)
     assert B.issubdtype(tf.float32, np.floating)
     assert B.issubdtype(torch.float32, np.floating)
+    assert B.issubdtype(jnp.float32, np.floating)
     assert not B.issubdtype(np.float32, np.integer)
     assert not B.issubdtype(tf.float32, np.integer)
     assert not B.issubdtype(torch.float32, np.integer)
+    assert not B.issubdtype(jnp.float32, np.integer)
 
 
 def test_dtype():
-    assert B.dtype(1) == int
-    assert B.dtype(1.0) == float
-    assert B.dtype(np.array(1, dtype=np.int32)) == np.int32
-    assert B.dtype(np.array(1.0, dtype=np.float32)) == np.float32
-    assert B.dtype(tf.constant(1, dtype=tf.int32)) == tf.int32
-    assert B.dtype(tf.constant(1.0, dtype=tf.float32)) == tf.float32
-    assert B.dtype(torch.tensor(1, dtype=torch.int32)) == torch.int32
-    assert B.dtype(torch.tensor(1.0, dtype=torch.float32)) == torch.float32
+    assert B.dtype(1) is int
+    assert B.dtype(1.0) is float
+    assert B.dtype(np.array(1, dtype=np.int32)) is np.int32
+    assert B.dtype(np.array(1.0, dtype=np.float32)) is np.float32
+    assert B.dtype(tf.constant(1, dtype=tf.int32)) is tf.int32
+    assert B.dtype(tf.constant(1.0, dtype=tf.float32)) is tf.float32
+    assert B.dtype(torch.tensor(1, dtype=torch.int32)) is torch.int32
+    assert B.dtype(torch.tensor(1.0, dtype=torch.float32)) is torch.float32
+    assert B.dtype(jnp.array(1, dtype=jnp.int32)) is jnp.int32
+    assert B.dtype(jnp.array(1.0, dtype=jnp.float32)) is jnp.float32
 
 
 @pytest.mark.parametrize('t', [B.NP, B.Framework])
@@ -127,3 +162,8 @@ def test_framework_tf(t):
 def test_framework_torch(t):
     assert isinstance(torch.tensor(1), t)
     assert isinstance(torch.float32, t)
+
+
+@pytest.mark.parametrize('t', [B.Jax, B.Framework])
+def test_framework_jax(t):
+    assert isinstance(jnp.asarray(1), t)
